@@ -21,6 +21,6 @@ class SockJSSereverSettings(object):
         self.listen_port = int(conf.get('listen_port', 8083))
         self.listen_location = conf.get('listen_location', '/ws')
         self.secret_key = conf.get('secret_key', 'not_set_secret_key')
-        self.sockjs_url = conf.get('sockjs_url', 'http://localhost:8083/ws')
+        self.sockjs_url = conf.get('sockjs_url', ['http://localhost:8083/ws'])
 
         self.router_settings = conf.get('router_settings', dict())
